__Author__='神秘的·'
__Project__='虹源三式'
__version__='定制版'
link='https://pypi.org/project/sycc/'
from time import sleep as dd
from sys import path
path.append('..')
import sys as s, time as t
def A():#作者&运算符相关
    print('\033[1;5;44m作者:' ,__Author__,'\033[0m')  
    print('\033[1;5;44m版本:',__version__ ,'\033[0m')
    print('\033[1;5;44mname:',__Project__,'\033[0m')
    print('\033[1;5;44mInformation:',link,'\033[0m')
    dd(0.5)
    print('\033[1;44m支持\033[0m','输入运算符(选项除外),\033[0m(使用英文字符)')
    dd(0.2)
pai2='π' #下面要用到，提前放上来 
def dw():#单位
    print('请自行换算单位并保持单位一致')
from math import pi as pai1
def aboutpi():
    print('''
    请选择π的值
    1.输入1,π为3.14
    2.输入2,π为''',pai1,
    '''
    3.输入3,保留π(π不换成数字)
    4.输入4,π为自定义大小(大于3 ,小于3.2)
    其他选项:
    5.输入5,切换模式
    6.输入不是1~5中的数,直接退出''')
#A()#test


import base64 as bs64
from sys import path
path.append('..')
from sys import exit as tc
from e.__init__ import *
import platform,webbrowser
global mac
os=platform.system()
def bzc(time_num):
    print('当前系统或设备不支持，如想使用,请pip install ycc')
    print('下面将为您自动打开ycc在pypi上的地址')
    webbrowser.open('https://pypi.org/project/ycc/')
    exitings(time_num)
    tc('谢谢使用')
if os=='Windows':
    import uuid
    try:
        mac= uuid.UUID(int=uuid.getnode()).hex[-12:]
        mac= ':'.join([mac[e:e + 2] for e in range(0, 11, 2)])
        mac=str(bs64.b64encode(mac.encode('utf-8')),'utf-8')
        mac=mac+'\n'
    except:
        bzc(1.5)
elif os=='Linux':
    import uuid
    try:
        import netifaces
    except ImportError:
        import os
        try:
            os.system('pip install netifaces')
        except:
            os.system('sudo pip install netifaces')
    net_list=netifaces.interfaces()
    if 'wlan0' in net_list:
        mac=netifaces.ifaddresses('wlan0')[netifaces.AF_LINK][0]['addr']
        mac=str(bs64.b64encode(mac.encode('utf-8')),'utf-8')
        mac='\n'+mac
    elif 'eth0' in net_list:
        mac=netifaces.ifaddresses('eth0')[netifaces.AF_LINK][0]['addr']
        mac=str(bs64.b64encode(mac.encode('utf-8')),'utf-8')
        mac='\n'+mac
    else:
        try:
            mac= uuid.UUID(int=uuid.getnode()).hex[-12:]
            mac= ':'.join([mac[e:e + 2] for e in range(0, 11, 2)])
            mac=str(bs64.b64encode(mac.encode('utf-8')),'utf-8')
            mac='\n'+mac
        except:
            bzc(2)
else:
    bzc(2)



from time import sleep as dd
def exit_tips(choose_quit):
	if choose_quit==1:
			print('\n准备退出中……(非正常退出请检查错误)\r')
	elif choose_quit==2:
			print('\n准备切换模式……(非正常切换请检查错误)')
def exitings(wait):
	exit_tips(1)
	while wait>=0:
		wait-=0.01
		dd(0.01)
		print('\r\033[1;1m\033[6;26;31m退出倒计时{:.1f}秒\033[0m'.format(abs(wait)),end="",flush=True)
	print('\n\033[1;23;33mFinish!\nEnd!\033[0m')
def switch(wt):#waiting time
	exit_tips(2)
	while wt>=0:
		wt-=0.01
		dd(0.01)
		print('\r\033[1;1m\033[6;26;32m切换倒计时{:.1f}秒\033[0m'.format(abs(wt)),end="",flush=True)
	print('\n\033[1;23;34mDone!\033[0m')


import sys
from pathlib import Path


class DirectionTree(object):
    """生成目录树
    @ pathname: 目标目录
    @ filename: 要保存成文件的名称
    """

    def __init__(self, pathname='/storage/emulated/0/ycc3/sycc/', filename='t.txt'):
        super(DirectionTree, self).__init__()
        self.pathname = Path(pathname)
        self.filename = filename
        self.tree = ''

    def set_path(self, pathname):
        self.pathname = Path(pathname)

    def set_filename(self, filename):
        self.filename = filename

    def generate_tree(self, n=0):
        if self.pathname.is_file():
            self.tree += '    |' * n + '-' * 2 + self.pathname.name + '\n'
        elif self.pathname.is_dir():
            self.tree += '    |' * n + '-' * 2 + \
                str(self.pathname.relative_to(self.pathname.parent)) + '\\' + '\n'

            for cp in self.pathname.iterdir():
                self.pathname = Path(cp)
                self.generate_tree(n + 1)

    def save_file(self):
        with open(self.filename, 'w', encoding='utf-8') as f:
            f.write(self.tree)


if __name__ == '__main__':
    dirtree = DirectionTree()
    # 命令参数个数为1，生成当前目录的目录树
    if len(sys.argv) == 1:
        dirtree.set_path(Path.cwd())
        dirtree.generate_tree()
        print(dirtree.tree)
    # 命令参数个数为2并且目录存在存在
    elif len(sys.argv) == 2 and Path(sys.argv[1]).exists():
        dirtree.set_path(sys.argv[1])
        dirtree.generate_tree()
        print(dirtree.tree)
    # 命令参数个数为3并且目录存在存在
    elif len(sys.argv) == 3 and Path(sys.argv[1]).exists():
        dirtree.set_path(sys.argv[1])
        dirtree.generate_tree()
        dirtree.set_filename(sys.argv[2])
        dirtree.save_file()
    else:  # 参数个数太多，无法解析
        print('命令行参数太多，请检查！')


from p.__init__ import *
from sys import path
path.append('..')
from e.__init__ import *
import platform
os=platform.system()
pai2='π'
def yh_error(p1,p2):
    e_back=p1+p2
    print(e_back+'请输入有效数字')
    print(e_back+'\033[6;31mError\033[0m\n')
    print('请选择\033[6;35m圆环\033[0m\033[1;1m模式重试')
    switch(2)
def part_yh():#圆环
    while True:
        r1=input('请输入外圆半径:')
        try:
        	r1=eval(r1)
        	if r1<=0:
        	    print('你输入的数太小\n请重新选择\033[6;35m圆环\033[0m\033[1;1m模式重试')
        	    switch(3)
        	    break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            yh_error('外圆半径',':')
            break
        r2=input('请输入内圆半径:')
        try:
        	r2=eval(r2)
        	if r2<=0:
        	    print('你输入的数太小\n请重新选择\033[6;35m圆环\033[0m\033[1;1m模式重试')
        	    switch(2)
        	    break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            yh_error('内圆半径',':')
            break
        try:
            if r2>=r1:
                print('①.内圆半径应<外圆半径\n②.2s后重新选择\033[6;35m圆环\033[0m\033[1;1m模式重试\n\033[7;35mtips:\033[0m\033[1;1m注意外圆半径和内圆半径的顺序')
                switch(3)
                break
        except Exception:
            print('出现\033[6;31mError\033[0m\n')
            print('请选择\033[6;35m圆环\033[0m\033[1;1m模式重试')
            switch(2)
            break
        print('【\033[6;35m圆环\033[0m\033[1;1m】')
        aboutpi()
        if os=='Linux':
            xxx=input('请输入(\033[1;32m1,2,3,4,5\033[0m\033[1;1m)中的一个数字:')
        elif os=='Windows':
            xxx=input('请输入1,2,3,4,5中的数字')
        print('')
        try:
            xxx=int(xxx)
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入正确的整数,不可以使用运算符')
        try:
            if xxx>5 or xxx<=0:
                end1=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
            elif xxx==5:
                print('-'*40)
                switch(0.1)
                break
            elif xxx==1:
                Sr1=r1*r1*3.14 #外圆s
                Sr2=r2*r2*3.14 #内圆s
                S=Sr1-Sr2     #圆环s
                C1=6.28*r1 #外圆c
                C2=6.28*r2 #内圆c 
                dw()
                print('=====计算结果=====')
                print('圆环面积=','{:.5f}'.format(S))
                print('外圆周长=','{:.4f}'.format(C1))
                print('内圆周长=','{:.4f}'.format(C2))
                print('外圆面积=','{:.5f}'.format(Sr1))
                print('内圆面积=','{:.5f}'.format(Sr2))
            elif xxx==2:
                Sr1=r1*r1*pai1 #外圆s #6
                Sr2=r2*r2*pai1 #内圆s #7
                S=Sr1-Sr2      #圆环s #6
                C1=2*pai1*r1 #外圆周长#6
                C2=2*pai1*r2 #内圆周长 #6
                print('=====计算结果=====')
                print('圆环面积=','{:.5f}'.format(S))
                print('外圆周长=','{:.4f}'.format(C1))
                print('内圆周长=','{:.4f}'.format(C2))
                print('外圆面积=','{:.5f}'.format(Sr1))
                print('内圆面积=','{:.5f}'.format(Sr2))
            elif xxx==3:
                Sr1=r1*r1 #外圆s 
                Sr2=r2*r2#内圆s
                S=Sr1-Sr2      #圆环s
                C1=2*r1 #外圆周长
                C2=2*r2#内圆周长
                dw()
                print('=====计算结果=====')
                print('圆环面积=','{:.5f}'.format(S),pai2) 
                print('外圆周长=','{:.4f}'.format(C1),pai2)
                print('内圆周长=','{:.4f}'.format(C2),pai2)
                print('外圆面积=','{:.5f}'.format(Sr1),pai2)
                print('内圆面积=','{:.5f}'.format(Sr2),pai2)
            elif xxx==4:
                defpi=input('请输入要自定义的π(大于等于3且小于3.2)->')
                try:
                    defpi=eval(defpi)
                    if defpi<3 or defpi >3.2:
        	            print('^大于3小于3.2^|||3s后进入切换模式\n请选择圆柱模式')
        	            switch(3)
        	            break
                    elif defpi >=3 and defpi <3.2:
                        Sr1=r1*r1*defpi    #外圆s
                        Sr2=r2*r2*defpi #内圆s
                        S=Sr1-Sr2             #圆环s
                        C1=2*defpi           #外圆周长
                        C2=2*defpi*r2    #内圆周长
                        dw()
                        print('=====计算结果=====')
                        print('圆环面积=','{:.5f}'.format(S))
                        print('外圆周长=','{:.4f}'.format(C1))
                        print('内圆周长=','{:.4f}'.format(C2))
                        print('外圆面积=','{:.5f}'.format(Sr1))
                        print('内圆面积=','{:.5f}'.format(Sr2))        	            
                except ZeroDivisionError:
        	        print('除数不能为0')
                except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
                    print('请输入正确的数字')
            else:
                end=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
        except Exception:
            print('\033[6;35m圆环\033[0m\033[1;1mbeta报告:在本模式中您的操作出现\033[1;1m\033[6;31mError\033[0m\n','\b已为您自动跳转选择模式,请选择\033[6;35m圆环\033[0m\033[1;1m模式')
            switch(1)
            break


from os.path import split as path1,realpath as path2,exists,getsize as size;from sys import argv as path3
import base64 as bs64
from sys import exit as tc
from sys import stdout
from sys import path
path.append("..")
from e.__init__ import *
from k.Mac import *
from v import *
import webbrowser
from platform import system as os_pd
now_path=path1(path2(path3[0]))[0]
if exists(now_path+'/v.txt')==False:
    with open(now_path+'/v.txt','a+'):
        if size(now_path+'/v.txt')>0:
            pass
        else:
            save_v(3,now_path+'/v.txt')
else:
    (open(now_path+'/v.txt','a+')).close()
    if size(now_path+'/v.txt')>0:
        pass
    else:
        save_v(3,now_path+'/v.txt')
if exists(now_path+'/.x.txt')==True:
    print('\033[1;1m\033[1;31m'+bs64.b64decode("".join(map(chr,[53,76,105,108,54,89,101,78,54,76,43,100,54,75,101,69,76,79,101,109,103,101,97,116,111,117,83,57,118,43,101,85,113,67,69,61]))).decode('utf8')+'\033[0m')
    dd(0.2)
    djs_s=5
    while djs_s>0:
        if djs_s==5:
            dd(0.02)
        djs_s-=1
        dd(1)
        print('\033[1;1m退出倒计时\033[0m:'+str(djs_s),end='\r',flush=True)
    tc()
def user_key():
    make=open(now_path+'/.txt',mode='a+')
    make.close()
    with open(now_path+'/.txt',mode='r') as disable:
        disable=disable.read()
        if mac in disable or load_v(now_path+'/v.txt')==0:
            stdout.write('\n黑名单用户,禁止使用')
            exitings(2)
            tc('黑名单用户,禁止使用')
    import base64 as bs64;'';"";username=bs64.b32decode(bs64.b64decode(bs64.b16decode(bs64.b85decode(bs64.b64decode("".join(map(chr,[83, 68, 104, 108, 79, 86, 108, 72, 89, 121, 48, 122, 97, 107, 103, 52, 75, 70, 86, 111, 83, 70, 112, 51, 81, 50, 70, 73, 79, 71, 86, 68, 90, 85, 103, 52, 84, 84, 66, 122, 83, 68, 104, 108, 83, 88, 86, 72, 74, 108, 90, 74, 97, 107, 103, 52, 86, 106, 108, 107, 82, 121, 104, 56, 83, 121, 49, 73, 79, 70, 90, 68, 99, 48, 100, 106, 89, 68, 78, 120, 83, 68, 103, 122, 80, 50, 70, 72, 89, 49, 108, 120, 89, 107, 103, 52, 77, 122, 57, 104, 82, 50, 78, 90, 99, 87, 73, 61]))).decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8');key=bs64.b64decode(bs64.b32decode(bs64.b16decode(bs64.b64decode('NEQ0RDVBNTY0RDM1MzIzMjRDNDI0NjQ3NTE1NzUzNDg0NzQ2NTk0NzQ1NUE1QTM1NDg1NTNEM0QzRDNEM0QzRA==').decode('utf-8')).decode('utf-8')).decode('utf-8')).decode('utf-8')
    def print(*arg,end='\n'):
        global print
        if key in arg or username in arg:
            with open(now_path+"/.txt", mode='a+',encoding='utf-8') as hmd_add:
                hmd_add.writelines(mac)
            stdout.write('非法操作，已进入黑名单')
        arg=''.join(str(i) for i in arg)
        stdout.write(arg+end)
    times=load_v(now_path+'/v.txt')
    if times<=0 and times>3:
        with open(now_path+"/.txt", mode='a+',encoding='utf-8') as hmd_add:
            hmd_add.writelines(mac)
        print('黑名单用户,禁止使用')
        exitings(2)
        tc()
    assert (times in range(1,4)),[print('\033[1;1m\033[1;31mError\033[0m:\033[1;1m非法操作\033[0m'),save_v(0,now_path+'/v.txt')
    ,(open(now_path+'/.x.txt','a+')).writelines(mac),exitings(1),dd(1),tc()]
    print('\n虹源三式提醒您:请输入Username和password')
    while True:
        print('当前剩余机会',times,'次')
        k_input=input('Username:')
        u_input=input('password:')
        if k_input==key and u_input==username:#后续加入其他账号
            print('\033[6;32m超级管理员,欢迎使用\033[0m\033[1;1m')
            save_v(3,now_path+'/v.txt')
            dd(0.2)
            print('用户名与密码正确,剩余机会已恢复为3')          
            break
        elif k_input!=key or u_input!=username:
            times=times-1
            save_v(times,now_path+'/v.txt')
            print('密码或用户名错误,你还有',times,'次机会')                
        else:
            times=times-1
            save_v(times,now_path+'/v.txt')
            print('密码或用户名错误,你还有',times,'次机会')
        if times<=0:
            with open(now_path+"/.txt", mode='a+',encoding='utf-8') as hmd_add:
                hmd_add.writelines(mac)
                if mac in now_path+'/.txt':
                    print('已加入黑名单')
                    exitings(1)
                    tc('禁止使用')
                else:
                    print('程序\033[1;31mERROR\033[0m,请联系lwb29@qq.com')
                    exitings(3)
                    tc()
user_key()


import pickle
def save_v(v,filename):
  f=open(filename,'wb')
  pickle.dump(v,f)
  f.close()
  return filename
 
def load_v(filename):
  with open(filename,'rb') as t:
      r=pickle.load(t)
  return r


from colorama import init
from time import sleep as dd
from sys import exit as tc
import platform as pd1
from sys import platform as pd2
os1=pd1.system()#大写
os2=pd2#
def pdios():
    print('正在判断系统')
    dd(0.4)
    print('\r检测到您的系统为',os1)
    if (os1=='Windows') or (os2=='windows'):
        print('*^_^* 欢迎Windows用户\n')
        init(autoreset=True)
    elif (os1=='Linux') or (os2=='linux'):
        print('$欢迎Linux用户\n')
        init(autoreset=False)
    else:
        print('虹源三式提醒您:不支持该系统,请联系lwb29@qq.com')
        dd(2)
        tc('exit')


#yz需要修复大量bug与无用行
from p.__init__ import *
from sys import path
path.append('..')
from e.__init__ import *
import platform
os=platform.system()
pai2='π'
yz_font='\033[1;99;36m圆柱\033[0m\033[1m'
def yz_error(error_back):
    print(error_back,'请输入有效数字')
    print(error_back,'\033[6;31mError\033[0m\n')
    print('请选择'+yz_font+'模式重试')
    switch(2)
def part_yz():#圆柱
    while True:
        r=input('请输入半径:')#半径输入
        try:
            r=eval(r)
            if r<=0:
                print('请输入有效数字\n请选择'+yz_font+'模式重试')
                switch(2)
                break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,KeyboardInterrupt,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            yz_error('半径:')
            break
        H=input('请输入高:')#高输入 
        try:
            H=eval(H)
            if H<=0:
                print('请输入有效数字\n请选择'+yz_font+'模式重试')
                switch(2)
                break
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,KeyboardInterrupt):
            yz_error('高:')
            break
        try:
            if H<=0 or r<=0:#请勿删除，仿照yh#用这个捕捉错误
                print('\033[7;35mtips:\033[0m\n\033[1;1m①.半径和高>0\n②.2s后重新选择'+yz_font+'模式使用')
                switch(3)
                break
        except Exception:
            print('出现\033[6;31mError\033[0m\n')
            print('请选择'+yz_font+'模式重试')
            switch(2)
            break
        print('【'+yz_font+'】')
        aboutpi()
        if os=='Linux':
            xxx=input('请输入(\033[1;32m1,2,3,4,5\033[0m\033[1;1m)中的一个数字:')
        elif os=='Windows':
            xxx=input('请输入1,2,3,4,5中的数字')
        try:
            xxx=int(xxx)
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,KeyboardInterrupt):
            print('请输入有效数字')
        try:
            if xxx>5 or xxx<=0:
                end1=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
            elif xxx==5:
                print('-'*40)
                print('切换模式')
                switch(0.1)
                break
            elif xxx==1:
                dw()
                sU=r*r*3.14#上圆s
                sD=sU*2#双圆s
                d=2*r  #直径
                C=d*3.14 #周长
                Sc=C*H #侧s
                S=sD+Sc #表s
                V=sU*H
                print('======计算结果======')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.5f}'.format(C))
                print('一个圆的面积=','{:.5f}'.format(sU))
                print('两个圆的面积=','{:.5f}'.format(sD))
                print('圆柱的侧面积=','{:.5f}'.format(Sc))
                print('圆柱的体积=','{:.5f}'.format(V))
                print('圆柱的表面积=','{:.5f}'.format(S))
            elif xxx==2:
                sU=r*r*pai1#上圆s
                sD=sU*2#双圆s
                d=2*r  #直径
                C=d*pai1 #周长
                Sc=C*H #侧s
                S=sD+Sc #表s
                V=sU*H
                dw()
                print('=====计算结果=====')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.5f}'.format(C))
                print('一个圆的面积=','{:.5f}'.format(sU))
                print('两个圆的面积=','{:.5f}'.format(sD))
                print('圆柱的侧面积=','{:.5f}'.format(Sc))
                print('圆柱的体积=','{:.5f}'.format(V))
                print('圆柱的表面积=','{:.5f}'.format(S))
            elif xxx==3:
                sU=r*r#上圆s 
                sD=sU*2#双圆s 
                d=2*r  #直径
                C=d #周长
                Sc=C*H #侧s 
                S=sD+Sc #表s 
                V=sU*H
                dw()
                print('=====计算结果=====')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.5f}'.format(C),pai2)
                print('一个圆的面积=','{:.5f}'.format(sU),pai2)
                print('两个圆的面积=','{:.5f}'.format(sD),pai2)
                print('圆柱的侧面积=','{:.5f}'.format(Sc),pai2)
                print('圆柱的体积=','{:.6f}'.format(V),pai2)
                print('圆柱的表面积=','{:.5f}'.format(S),pai2)
            elif xxx==4:
                defpi=input('请输入要自定义的π(大于等于3且小于3.2)->')
                try:
                    defpi=eval(defpi)
                    if defpi<3 or defpi>3.2:
                        print('^大于3小于3.2^|||3s后进入切换模式\n请选择'+yz_font+'模式')
                        switch(3)
                        break
                    else:
                        sU=r*r*defpi#上圆s
                        sD=sU*2#双圆s
                        d=2*r  #直径
                        C=d*defpi #周长
                        Sc=C*H #侧s
                        S=sD+Sc #表s
                        V=sU*H#体积
                        dw()
                        print('=====计算结果=====')
                        print('当半径=',r,'直径=',d,'高=',H,'π=',defpi,'时')
                        print('\n一个圆的周长=','{:.6f}'.format(C))
                        print('一个圆的面积=','{:.6f}'.format(sU))
                        print('两个圆的面积=','{:.6f}'.format(sD))
                        print('圆柱的侧面积=','{:.6f}'.format(Sc))
                        print('圆柱的体积=','{:.6f}'.format(V))
                        print('圆柱的表面积=','{:.6f}'.format(S))
                except ZeroDivisionError:
           	     print('除数不能为0')
                except (Exception,KeyboardInterrupt):
                    print('请输入指定范围的数字')
            else:
                end1=sj.now()-start
                print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
                exitings(5)
                tc('谢谢使用')
        except Exception:
            print('\n'+yz_font+'beta报告:在本模式中您的操作出现\033[1;1m\033[6;31mError\033[0m\n','\b已为您自动跳转选择模式,请选择圆柱模式')
            switch(1)
            break


from sys import path
path.append('..')
from p.__init__ import *
from e.__init__ import *
import platform
os=platform.system()
pai2='π'
qt_font='\033[1;33m球体\033[0m\033[1;1m'
def part_qt():
    #print('球体-β')
    while True:
        try:
            r=eval(input('请输入半径:'))
            d=2*r
            if r<=0:
        	    print('你输入的数太小\n请重新选择'+qt_font+'模式重试')
        	    switch(3)
        	    break
        except ZeroDivisionError:
            print('除数不能为0')
        except Exception:
            print('半径:请输入有效数字')
            print('半径:\033[6;31mError\033[0m\n')
            print('请选择'+qt_font+'模式重试')
            switch(2)
            break
        print('【'+qt_font+'】')
        aboutpi()
        if os=='Linux':
            xxx=input('请输入(\033[1;32m1,2,3,4,5\033[0m\033[1;1m)中的一个数字:')
        elif os=='Windows':
            xxx=input('请输入1,2,3,4,5中的数字')
        print('')
        try:
            xxx=int(xxx)
        except ZeroDivisionError:
            print('除数不能为0')
        except (Exception,IOError,ValueError,TypeError,SyntaxError,EOFError,NameError,KeyboardInterrupt):
            print('请输入指定范围的整数,不可以使用运算符')
            switch(0.3)
            break
        try:
        	if xxx>5 or xxx<=0:
        		end1=sj.now()-start
        		print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在3s后关闭,谢谢使用')
        		exitings(3)
        		tc('谢谢使用')
        	elif xxx==5:
        		print('-'*40)
        		switch(0.3)
        		break
        	elif xxx==1:
        	    S=4*3.14*r**2
        	    c=2*3.14*r
        	    s=2*3.14*r
        	    v=4/3*3.14*pow(r,3)
        	    dw()
        	    print('======计算结果======')
        	    print('当半径=',r,'直径=',d,'时')
        	    print('截面面积={:.4f}'.format(s))
        	    print('截面周长={:.4f}'.format(c))
        	    print('表面积={:.4f}'.format(S))
        	    print('体积={:.4f}'.format(v)+'\n')
        	elif xxx==2:
        	    s=2*pai1*r
        	    c=2*pai1*r
        	    S=4*pai1*pow(r,2)
        	    v=4/3*pai1*r**3
        	    dw()
        	    print('======计算结果======')
        	    print('当半径=',r,'直径=',d,'时')
        	    print('截面面积={:.4f}'.format(s))
        	    print('截面周长={:.4f}'.format(c))
        	    print('表面积={:.4f}'.format(S))
        	    print('体积={:.4f}'.format(v)+'\n')
        	elif xxx==3:
        	    r2=r**2#r²+pai2#截
        	    s=r2*4#4r²+pai2#表
        	    v=r**3*4/3#
        	    c=2*r
        	    print('======计算结果======')
        	    print('当半径=',r,'直径=',d,'时')
        	    print('截面面积={:.4f}'.format(r2)+pai2)
        	    print('截面周长={:.4f}'.format(c)+pai2)
        	    print('表面积={:.4f}'.format(s)+pai2)
        	    print('体积={:.4f}'.format(v)+pai2+'\n')
        	elif xxx==4:
        	    defpi=input('请输入要自定义的π(大于等于3且小于3.2)->')
        	    try:
        	        defpi=eval(defpi)
        	        if defpi<3 or defpi >3.2:
        	            print('^大于3小于3.2^|||3s后进入切换模式\n请选择'+qt_font+'模式')
        	            switch(3)
        	            break
        	        else:
        	            s=defpi*r**2
        	            S=4*defpi*r**2
        	            v=4/3*defpi*r**3
        	            c=2*defpi*r
        	            print('======计算结果======')
        	            print('当半径=',r,'直径=',d,'π=',defpi,'时')
        	            print('截面面积={:.6f}'.format(s))
        	            print('截面周长={:.6f}'.format(c))
        	            print('表面积={:.6f}'.format(S))
        	            print('体积={:.6f}'.format(v)+'\n')
        	    except ZeroDivisionError:
        	        print('除数不能为0')
        	    except (Exception,KeyboardInterrupt):
        	        print('请输入指定范围的数字')
        	else:
        	    end1=sj.now()-start
        	    print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5s后关闭,谢谢使用')
        	    exitings(5)
        	    tc('谢谢使用')
        except Exception as e:
            print(e)
            print(qt_font+'beta报告:在本模式中您的操作出现\033[1;1m\033[6;31mError\033[0m\n','\b已为您自动跳转选择模式,请选择'+qt_font+'模式')
            switch(1)